from setuptools import setup
setup(name="wrs",
version="0.1",
description="Split string without eliminating delimeter",
long_description = "This is a function package split string string into list without removing delimeter from string, can accept more than one delimeter at once in format:  'Delimeter1 | Delimeter2 | Delimeter3 | ...' ",
author="Rao Hamza",
packages=['wrs'],
install_requires=[])